#automatically import casper on initialiasation so we don't have to multiply import

from .casper import *

